@@ -79,11 +79,9 @@ class CfnMicrosoftAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
@@ -474,11 +472,9 @@ class CfnSimpleAD(
 
     @jsii.member(jsii_name="inspect")
     def inspect(self, inspector: aws_cdk.core.TreeInspector) -> None:
-        '''(experimental) Examines the CloudFormation resource and discloses attributes.
+        '''Examines the CloudFormation resource and discloses attributes.
 
         :param inspector: - tree inspector to collect and process attributes.
-
-        :stability: experimental
         '''
         return typing.cast(None, jsii.invoke(self, "inspect", [inspector]))
 
